@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2012-2013  Tetsuo Handa
  *
- * Version: 0.1   2013/01/06
+ * Version: 0.2   2016/10/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -45,12 +45,14 @@ static void set(const char *str)
 {
 	fprintf(fp, "%s\n", str);
 	fflush(fp);
+	errno = 0;
 }
 
 static void unset(const char *str)
 {
 	fprintf(fp, "delete %s\n", str);
 	fflush(fp);
+	errno = 0;
 }
 
 static void unset2(const char *str)
@@ -65,6 +67,7 @@ static void unset2(const char *str)
 	}
 	fprintf(fp, "delete %s\n", str);
 	fflush(fp);
+	errno = 0;
 }
 
 static void check(const char *prompt, int result)
@@ -74,7 +77,7 @@ static void check(const char *prompt, int result)
 	if (!result) {
 		fprintf(stderr, "Err: %s(%d)\n", strerror(err), err);
 		{
-			int fd2 = open("/proc/caitsith/self_domain", O_RDONLY);
+			int fd2 = open(POLDIR "/self_domain", O_RDONLY);
 			char c;
 			fprintf(stderr, "task.domain=\"");
 			while (read(fd2, &c, 1) == 1)
@@ -82,6 +85,7 @@ static void check(const char *prompt, int result)
 			close(fd2);
 			fprintf(stderr, "\"\n");
 		}
+		kill(1, SIGCONT);
 		exit(1);
 	}
 	printf("\n");
@@ -91,7 +95,7 @@ static void check(const char *prompt, int result)
 static void check_init(const char *prompt, const char *expected)
 {
 	int result;
-	int fd = open("/proc/caitsith/.process_status", O_RDWR);
+	int fd = open(POLDIR "/.process_status", O_RDWR);
 	char buffer[1024];
 	char *cp;
 	memset(buffer, 0, sizeof(buffer));
@@ -108,6 +112,7 @@ static void check_init(const char *prompt, const char *expected)
 	if (!result) {
 		fprintf(stderr, "Err: expected='%s' result='%s'\n",
 			expected, buffer);
+		kill(1, SIGCONT);
 		exit(1);
 	}
 	printf("\n");
@@ -116,7 +121,7 @@ static void check_init(const char *prompt, const char *expected)
 
 static void test_task_transition(void)
 {
-	int fd = open("/proc/caitsith/self_domain", O_WRONLY);
+	int fd = open(POLDIR "/self_domain", O_WRONLY);
 	char *policy;
 
 	policy = "100 acl manual_domain_transition\n"
@@ -460,7 +465,9 @@ static void test_file_create(void)
 	unset(policy);
 
 	policy = "100 acl create\n"
-		"0 allow path=\"dev(8,1):/tmp/file\" path.parent.uid=0\n"
+		"0 allow path=\"dev(¥$,¥$):/tmp/file\" path.parent.uid=0\n"
+		"0 allow path=\"/tmp/file\" path.parent.uid=0\n"
+		"0 allow path=\"dev(¥$,¥$):/file\" path.parent.uid=0\n"
 		"1 deny\n";
 	set(policy);
 	unlink("/tmp/file");
@@ -1778,18 +1785,44 @@ static void test_file_misc(void)
 	unset(buffer);
 }
 
-int main(int argc, char *argv[])
+static void reset_policy(void)
 {
+	FILE *fp2 = fopen(POLDIR "/policy", "r");
+	FILE *fp1 = fopen(POLDIR "/policy", "w");
+	if (!fp1 || !fp2) {
+		fprintf(stderr, " Can't open " POLDIR "/policy\n");
+		exit(1);
+	}
+	while (1) {
+		const int c = fgetc(fp2);
+		if (c == EOF)
+			break;
+		fputc(c, fp1);
+		if (c == '\n')
+			fprintf(fp1, "delete ");
+	}
+	fclose(fp2);
+	fclose(fp1);
+
+	/* Do not leave the init process in stopped state. */
+	kill(1, SIGCONT);
+	
 	/* Undo mount("/", MS_REC|MS_SHARED) made by systemd. */
 	mount(NULL, "/", NULL, MS_REC|MS_PRIVATE, NULL);
+}
 
-	fp = fopen("/proc/caitsith/policy", "w");
+int main(int argc, char *argv[])
+{
+	reset_policy();
+
+	fp = fopen(POLDIR "/policy", "w");
 	if (!fp) {
-		fprintf(stderr, " Can't open /proc/caitsith/policy\n");
+		fprintf(stderr, " Can't open " POLDIR "/policy\n");
 		return 1;
 	}
 	fprintf(fp, "quota audit[0]"
 		" allowed=1024 unmatched=1024 denied=1024\n");
+	fflush(fp);
 
 	test_task_transition();
 	test_file_read();
