@@ -57,7 +57,7 @@ static void check(const char *prompt, int result)
 	if (!result) {
 		fprintf(stderr, "Err: %s(%d)\n", strerror(err), err);
 		{
-			int fd2 = open("/proc/caitsith/self_domain", O_RDONLY);
+			int fd2 = open(POLDIR "/self_domain", O_RDONLY);
 			char c;
 			fprintf(stderr, "task.domain=\"");
 			while (read(fd2, &c, 1) == 1)
@@ -65,7 +65,6 @@ static void check(const char *prompt, int result)
 			close(fd2);
 			fprintf(stderr, "\"\n");
 		}
-		/* Do not leave the init process in stopped state. */
 		kill(1, SIGCONT);
 		exit(1);
 	}
@@ -76,7 +75,7 @@ static void check(const char *prompt, int result)
 static void check_init(const char *prompt, const char *expected)
 {
 	int result;
-	int fd = open("/proc/caitsith/.process_status", O_RDWR);
+	int fd = open(POLDIR "/.process_status", O_RDWR);
 	char buffer[1024];
 	char *cp;
 	memset(buffer, 0, sizeof(buffer));
@@ -93,6 +92,7 @@ static void check_init(const char *prompt, const char *expected)
 	if (!result) {
 		fprintf(stderr, "Err: expected='%s' result='%s'\n",
 			expected, buffer);
+		kill(1, SIGCONT);
 		exit(1);
 	}
 	printf("\n");
@@ -101,7 +101,7 @@ static void check_init(const char *prompt, const char *expected)
 
 static void test_task_transition(void)
 {
-	int fd = open("/proc/caitsith/self_domain", O_WRONLY);
+	int fd = open(POLDIR "/self_domain", O_WRONLY);
 	char *policy;
 
 	policy = "100 acl manual_domain_transition\n"
@@ -1979,30 +1979,45 @@ static void test_file_misc(void)
 	unset(buffer);
 }
 
-int main(int argc, char *argv[])
+static void reset_policy(void)
 {
-	FILE *fp2 = fopen("/proc/caitsith/policy", "r");
-	fp = fopen("/proc/caitsith/policy", "w");
-	if (!fp || !fp2) {
-		fprintf(stderr, " Can't open /proc/caitsith/policy\n");
-		return 1;
+	FILE *fp2 = fopen(POLDIR "/policy", "r");
+	FILE *fp1 = fopen(POLDIR "/policy", "w");
+	if (!fp1 || !fp2) {
+		fprintf(stderr, " Can't open " POLDIR "/policy\n");
+		exit(1);
 	}
 	while (1) {
 		const int c = fgetc(fp2);
 		if (c == EOF)
 			break;
-		fputc(c, fp);
+		fputc(c, fp1);
 		if (c == '\n')
-			fprintf(fp, "delete ");
+			fprintf(fp1, "delete ");
 	}
 	fclose(fp2);
+	fclose(fp1);
+
+	/* Do not leave the init process in stopped state. */
+	kill(1, SIGCONT);
+	
+	/* Undo mount("/", MS_REC|MS_SHARED) made by systemd. */
+	mount(NULL, "/", NULL, MS_REC|MS_PRIVATE, NULL);
+}
+
+int main(int argc, char *argv[])
+{
+	reset_policy();
+
+	fp = fopen(POLDIR "/policy", "w");
+	if (!fp) {
+		fprintf(stderr, " Can't open " POLDIR "/policy\n");
+		return 1;
+	}
 	fprintf(fp, "quota audit[0]"
 		" allowed=1024 unmatched=1024 denied=1024\n");
 	fflush(fp);
 
-	/* Undo mount("/", MS_REC|MS_SHARED) made by systemd. */
-	mount(NULL, "/", NULL, MS_REC|MS_PRIVATE, NULL);
-
 	test_task_transition();
 	test_file_read();
 	test_file_write();
