@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2012-2013  Tetsuo Handa
  *
- * Version: 0.1   2013/07/06
+ * Version: 0.2   2016/10/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -27,6 +27,7 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <time.h>
+#include <signal.h>
 #include <sys/mount.h>
 #ifndef MS_REC
 #define MS_REC      16384
@@ -771,8 +772,8 @@ static unsigned int tests_now = 0;
 
 static void check_policy_written(const _Bool valid)
 {
-	int fd1 = open("/proc/caitsith/policy", O_RDWR);
-	int fd2 = open("/proc/caitsith/policy", O_RDWR);
+	int fd1 = open(POLDIR "/policy", O_RDWR);
+	int fd2 = open(POLDIR "/policy", O_RDWR);
 	int len = strlen(policy);
 	int ret;
 	char *buffer;
@@ -897,12 +898,36 @@ static void check_righthand(const int mac, const int p1, const _Bool org_valid)
 	}
 }
 
+static void reset_policy(void)
+{
+	FILE *fp2 = fopen(POLDIR "/policy", "r");
+	FILE *fp1 = fopen(POLDIR "/policy", "w");
+	if (!fp1 || !fp2) {
+		fprintf(stderr, " Can't open " POLDIR "/policy\n");
+		exit(1);
+	}
+	while (1) {
+		const int c = fgetc(fp2);
+		if (c == EOF)
+			break;
+		fputc(c, fp1);
+		if (c == '\n')
+			fprintf(fp1, "delete ");
+	}
+	fclose(fp2);
+	fclose(fp1);
+
+	/* Do not leave the init process in stopped state. */
+	kill(1, SIGCONT);
+	
+	/* Undo mount("/", MS_REC|MS_SHARED) made by systemd. */
+	mount(NULL, "/", NULL, MS_REC|MS_PRIVATE, NULL);
+}
+
 int main(int argc, char *argv[]) {
 	int mac;
 
-	/* Undo mount("/", MS_REC|MS_SHARED) made by systemd. */
-	mount(NULL, "/", NULL, MS_REC|MS_PRIVATE, NULL);
-
+	reset_policy();
 	if (argc > 1)
 		tests_start = atoi(argv[1]);
 	for (mac = 0; mac < CCS_MAX_MAC_INDEX; mac++) {
